==> tmaid-2.4.2.tar.gz: tmaid-2.4.2/src/prop.h <==
/*
    Text maid
    copyright (c) 1998-2005 Kazuki IWAMOTO http://www.maid.org/ iwm@maid.org

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
*/
#ifndef __PROPERTY_H__
#define __PROPERTY_H__


#include "tmaid.h"


#ifdef __cplusplus
extern "C" {
#endif /* __cplusplus */


/******************************************************************************
*                                                                             *
* ja:プロパティ関数群                                                         *
*                                                                             *
******************************************************************************/
/*  ja:プロパティをコピーする
    ft_dst,コピー先
    ft_src,コピー元                                                         */
void
property_copy (FileType *ft_dst,
               FileType *ft_src);


/*  ja:プロパティを変更する
    tmaid,ウインドウ情報
       ft,ファイルタイプ                                                    */
void
property_change (TmaidWindow *tmaid,
                 FileType    *ft);


/******************************************************************************
*                                                                             *
* ja:プロパティダイアログ関数群                                               *
*                                                                             *
******************************************************************************/
/*  ja:プロパティダイアログ表示
    parent,親ウインドウ
        ft,ファイルタイプ
       RET,TRUE:OK,FALSE:Cancel                                             */
gboolean
property_dialog (GtkWindow *parent,
                 FileType  *ft);


#ifdef __cplusplus
}
#endif /* __cplusplus */


#endif /* __PROPERTY_H__ */

==> tmaid-2.5.5.tar.gz: tmaid-2.5.5/src/prop.h <==
/*
    Text maid
    copyright (c) 1998-2005 Kazuki IWAMOTO http://www.maid.org/ iwm@maid.org

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
*/
#ifndef __PROPERTY_H__
#define __PROPERTY_H__


#include "tmaid.h"


#ifdef __cplusplus
extern "C" {
#endif /* __cplusplus */


/******************************************************************************
*                                                                             *
* ja:プロパティ関数群                                                         *
*                                                                             *
******************************************************************************/
/*  ja:プロパティをコピーする
    ft_dst,コピー先
    ft_src,コピー元                                                         */
void
property_copy (FileType *ft_dst,
               FileType *ft_src);


/*  ja:プロパティを変更する
    tmaid,ウインドウ情報
       ft,ファイルタイプ                                                    */
void
property_change (TmaidWindow *tmaid,
                 FileType    *ft);


/******************************************************************************
*                                                                             *
* ja:プロパティダイアログ関数群                                               *
*                                                                             *
******************************************************************************/
/*  ja:プロパティダイアログ表示
    parent,親ウインドウ
        ft,ファイルタイプ
       RET,TRUE:OK,FALSE:Cancel                                             */
gboolean
property_dialog (GtkWindow *parent,
                 FileType  *ft);


#ifdef __cplusplus
}
#endif /* __cplusplus */


#endif /* __PROPERTY_H__ */
